<?php

/**
  * Nucleus: PHP/MySQL Weblog CMS (http://nucleuscms.org/) 
  * Copyright (C) 2002-2004 The Nucleus Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
  * (see nucleus/documentation/index.html#license for more info)
  *
**/

if (! function_exists(redirect) ) {
    function redirect($url) {
    	$url = preg_replace('|[^a-z0-9-~+_.?#=&;,/:@%]|i', '', $url);
    	header('Location: ' . $url);
    	exit;
    }
}

class NP_Blacklist extends NucleusPlugin {
	function getName() 		  { return 'Blacklist'; }
	function getAuthor()  	  { return 'xiffy'; }
	function getURL()  		  { return 'http://xiffy.nl/weblog'; }
	function getVersion() 	  { return '0.96 final'; }
	function getDescription() { return 'Blacklist for commentspammers';	}
	function supportsFeature($what) {
		switch($what) {
		    case 'SqlTablePrefix':
				return 1;
			default:
				return 0;
		}
	}

    function install() {
        // create some options
        $this->createOption('enabled','Blacklist engine enabled?','yesno','yes');
        $this->createOption('redirect','To which URL should spammers be redireted?','text','http://spamtrap.xiffy.nl/');
        $this->createOption('update','From which URL should we get a fresh blacklist copy?', 'text','http://www.jayallen.org/comment_spam/blacklist.txt');
        $this->createOption('referrerblock','Enable referrer based blocking?','yesno','yes');
        $this->createOption('ipblock','Enable ip based blocking?','yesno','no');
        $this->createOption('ipthreshold','How many spam attempts will block an IP address?','text','10');
    }

	function unInstall() {}

    function getPluginOption ($name) {
        return $this->getOption($name);
    }

	function getEventList() {
		return array('QuickMenu','PreAddComment','PreSkinParse','PreActionAddComment', 'SpamCheck');
	}

	function hasAdminArea() {
		return 1;
	}

	function event_QuickMenu(&$data) {
		global $member, $nucleus, $blogid;
		// only show to admins
		if (preg_match("/MD$/", $nucleus['version'])) {
			$isblogadmin = $member->isBlogAdmin(-1);
		} else {
			$isblogadmin = $member->isBlogAdmin($blogid);
		}
		if (!($member->isLoggedIn() && ($member->isAdmin() | $isblogadmin))) return;
		array_push(
			$data['options'],
			array(
				'title' => 'Blacklist',
				'url' => $this->getAdminURL(),
				'tooltip' => 'Manage your blacklist'
			)
		);
	}

    // for other plugin writers ...
    function event_SpamCheck (&$data) {
        global $DIR_PLUGINS;
        if (isset($data['spamcheck']['result']) &&
            $data['spamcheck']['result'] == true)     {
            // Already checked... and is spam
            return;
        }
        // Check for spam
        $result = $this->blacklist($data['spamcheck']['type'], $data['spamcheck']['data'], $data['spamcheck']['ipblock']);

        if ($result) {
            // Spam found
            // logging !
            pbl_logspammer($data['spamcheck']['type'].': '.$result);
            if  (isset($data['spamcheck']['return']) && $data['spamcheck']['return'] == true) {
                // Return to caller
                $data['spamcheck']['result'] = true;
                return;
            } else {
                redirect($this->getOption('redirect'));
            }
        }
    }

    // will become obsolete when nucleus is patched ...
	function event_PreAddComment(&$data) {
	    $comment = $data['comment'];
	    $result = $this->blacklist('comment',$comment['body'].' '.$comment['host'].' '.$comment['user'].' '.$comment['userid']);
        if ($result != '') {
            pbl_logspammer('comment: '.$result);
            redirect($this->getOption('redirect'));
        }
    }

	// preskinparse will check the referrer for spamming attempts
	// only when option enabled !
	// logging also only when option enabled ...
	function event_PreSkinParse(&$data) {
        $result = $this->blacklist('refer','');
        if ($result != '') {
            pbl_logspammer('referrer: '.$result);
            redirect($this->getOption('redirect'));
        }
	}

	function event_PreActionAddComment(&$data) {
	    // test referrer ...
        $result = $this->blacklist('comment', $data['body'].' '.$data['user'].' '.$data['userid']);
        if ($result != '') {
            pbl_logspammer('comment: '.$result);
            redirect($this->getOption('redirect'));
        }
	}


	function blacklist($type,$testString, $ipblock = true) {
        global $DIR_PLUGINS;
	    if ($this->getOption('enabled') == 'yes') {
            include_once($DIR_PLUGINS."blacklist/blacklist_lib.php");
            // update the blacklist first file
            pbl_updateblacklist($this->getOption('update'),false);
            if ($ipblock) {
                $ipblock = $this->getOption('ipblock');
            } else {
                $ipblock = 'no';
            }
            $refer = parse_url($_SERVER['HTTP_REFERER']);
            $refer = $refer['host'];
            if ($this->getOption('referrerblock') == 'yes')  {
                $spamDetected = pbl_checkforspam($refer, $ipblock , $this->getOption('ipthreshold'), true);
                if($spamDetected != "")  {
                    return $spamDetected;
                }
            }
            if ($testString != '') {
                $spamDetected = pbl_checkforspam($testString, $ipblock, $this->getOption('ipthreshold'), true);
                if($spamDetected != "")  {
                    return $spamDetected;
                }
            }
        }
    }
}
?>