<?php

/**
  * BLOG:CMS: PHP/MySQL Personal Content Management System (CMS)
  * http://blogcms.com/
  * ----------------------------------------------------------------
  *
  * Copyright (C) 2003-2005 Radek HULN
  * http://hulan.cz/contact/
  *
  * ----------------------------------------------------------------
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
**/

class NP_FancyText extends NucleusPlugin {

var $js,$threads,$replytothistext,$commentinspired,$inspiredby;

  function getName( ){return 'FancyText';} 
  function getAuthor( ){return 'Radek HULAN';} 
  function getURL( ){return 'http://hulan.cz/blog/';} 
  function getVersion( ){return '3.4';} 
  function getDescription( ){return 'Smilies, threaded-discussion in comments, article formatting.';} 
  
  function install( ){
    $this->createOption( "commentinspired", "This comment inspired 'child':", "text", "this comment inspired");
    $this->createOption( "inspiredby", "Inspired by 'parent':", "text", "inspired by");
    $this->createOption( "replytothistext", "Reply to this comment text:", "text", "reply to this comment");
    $this->createOption( "allowthreads", "Enable threaded discussions for COMMENTS (yes/no):", "yesno", "yes");
    $this->createOption( "addp", "Convert line breaks to paragraphs in ARTICLE (yes/no):", "yesno", "yes");
    $this->createOption( "smiliesarticles", "Convert smilies articles (yes/no):", "yesno", "yes");
    $this->createOption( "smiliescomments", "Convert smilies comments (yes/no):", "yesno", "yes");
    $this->createOption( "ampersands", "Encode ampersands?", "yesno", "yes");
    // disable auto-linebreak conversions
    sql_query( "UPDATE " . sql_table( 'blog') . " SET bconvertbreaks=0");
  } 
  
  function supportsFeature($feature) { if ($feature=='SqlTablePrefix') return 1; else return 0;}
  
  function getEventList( ){
      return array( 
        'PreAddComment', 
        'PreComment', 
        'PreAddItem', 
        'PreUpdateItem', 
        'PreItem'
      );
  } 
  
  function autop( $text) {
      // encode ampersands
      if ( strtolower( $this->getOption( "addp") != 'yes'))
	  	if ($this->getOption( "ampersands") == 'yes' )
	  		return preg_replace( '/&([^#])(?![a-z]{1,8};)/', '&#38;$1', $text);
		else
			return $text;
      // linebreaks to paragraphs conversion
      return paragraph( $text, false);
  } 
  
  function event_PreAddItem(&$data){ 
    $parts=array('body','more');
    foreach ($parts as $part) $data[$part] = $this->autop($data[$part]);
  } 
  
  function event_PreUpdateItem(&$data){
    $this->event_PreAddItem($data);
  } 
  
  function event_PreAddComment(&$data){
	// convert pseudo tags into real XHTML
	$data['comment']['body'] = commentformatting( $data['comment']['body'] );
  } 
  
  function init(){
    $this->threads=($this->getOption("allowthreads")!='no');
    $this->replytothistext=$this->getOption("replytothistext");
    $this->inspiredby=$this->getOption("inspiredby");
    $this->commentinspired=$this->getOption("commentinspired");
  }

	function event_PreComment($data) {
	  if (!isset($this->curItem)) return;
    
    /* comment id */
    $this->commentSeq++;
    $this->permacommentid=strval($data['comment']['commentid']);
    $id=strval($data['comment']['commentid']);

    /* old style comments? */
    $pos=strpos($data['comment']['body'],'<p>');
    if ($pos===false) $data['comment']['body']="<p>".trim($data['comment']['body'])."</p>";

    // *******************************************
    // threaded discussion - JavaScript - PARENTS
    // *******************************************
    if ($this->threads){
      $offset=0;
      $parents="";
      do{
        $pos=strpos(substr($data['comment']['body'],$offset),'[');
        if ( !($pos===false) ){
          $pos=$pos+$offset;
          $offset=$pos+1;
          if ( ereg("^([0-9]+)].*$",substr($data['comment']['body'],$offset,10),$r) ){
            $cid=$r[1];
            if (intval($cid)<$this->commentSeq){
              /* get comment author name */
              $query=sql_query("SELECT cmember, cuser FROM ".sql_table('comment')." WHERE citem=".strval($this->curItem)." ORDER BY ctime, cnumber ASC LIMIT ".strval(intval($cid)-1).",1");
              if ($row=sql_fetch_object($query)){
                if ($row->cmember>0){
                  $query=sql_query("SELECT mname FROM ".sql_table('member')." WHERE mnumber=".strval($row->cmember));
                  if ($row=sql_fetch_object($query)) $name=$row->mname;
                } else {
                  $name=$row->cuser;
                }
              }
              $data['comment']['body']=str_replace('['.$cid.']','<span>'.$this->inspiredby.' '.'<a href="#cmmnt'.$cid.'">'.$name.' &#8212; #'.$cid."</a></span>",$data['comment']['body']);
              if (!empty($parents)) $parents.=',';
              $parents.="'cmmnt".$cid."'";
            } else {
              if (intval($cid)==$this->commentSeq){
                $data['comment']['body']=str_replace('['.$cid.']','<span>[self-reference not allowed: '.$cid.']</span>',$data['comment']['body']);
              } else {
                $data['comment']['body']=str_replace('['.$cid.']','<span>[future items not allowed: '.$cid.']</span>',$data['comment']['body']);
              }
            }
          }
        }
      } while (!($pos===false));
    }
    
    // *******************************************
    // threaded discussion - JavaScript - CHILDREN
    // *******************************************
    if ($this->threads){
      /* create links to childs */
 		  $data['comment']['body'].="<a href=\"#commentform\" title=\"Reply\">".$this->replytothistext."</a>";
      
      $query=sql_query("SELECT cbody, cmember, cuser FROM ".sql_table('comment')." WHERE citem=".strval($this->curItem)." ORDER BY ctime, cnumber ASC LIMIT ".strval($this->commentSeq).",100");
      $rownumber=$this->commentSeq;
      $first=true;
      
      $children="";
      while ($row=sql_fetch_object($query)){
        $rownumber++;
        if ( !(strpos(sql_unescape($row->cbody),'['.strval($this->commentSeq).']')===false) ||
             !(strpos(sql_unescape($row->cbody),'[<a href="#cmmnt'.strval($this->commentSeq).'">ad '.strval($this->commentSeq).'</a>]')===false)
        ) {
          if ($first) $data['comment']['body'].="<ol>";
          if ($row->cmember>0){
            $queryname=sql_query("SELECT mname FROM ".sql_table('member')." WHERE mnumber=".strval($row->cmember));
            if ($rowname=sql_fetch_object($queryname)) $name=$rowname->mname;
          } else {
            $name=$row->cuser;
          }
          $first=false;
          $data['comment']['body'].='<li>'.$this->commentinspired.' <a href="#cmmnt'.strval($rownumber).'">'.$name.' &#8212; #'.strval($rownumber).' </a></li>';
          if (!empty($children)) $children.=',';
          $children.="'cmmnt".strval($rownumber)."'";
        }
      }
      if (!$first) $data['comment']['body'].='</ol>';
    }

    /* emoticons */
		if ( $this->getOption( "smiliescomments") == 'yes' ) $this->doSmilies($data['comment']['body']);

		/* relative comment id */
	  $pos=strpos($data['comment']['body'],'<p>');
	  if ($pos===false) {
	    $data['comment']['body']="<p id='cmmnt".strval($this->commentSeq)."'>".trim($data['comment']['body'])."</p>";
	    $data['comment']['body']=str_replace("</p></p>","</p>",$data['comment']['body']);
	  } else {
	    $pos=strpos($data['comment']['body'],'>');
	    if ($pos!==false)
	      $data['comment']['body'] = substr($data['comment']['body'],0,$pos)." id='cmmnt".strval($this->commentSeq)."' ".substr($data['comment']['body'],$pos);
    }
	}

  function event_PreItem( $data){
      /* item id */
      $this->curItem = $data['item']->itemid;
      /* relative comment number */
      $this->commentSeq = 0;
      /* smileys */
      if ( $this->getOption( "smiliesarticles") == 'yes' ) {
        $this->doSmilies( $data['item']->body);
        $this->doSmilies( $data['item']->more);
      }
  } 
  
  function doSmilies( &$data)
  {
      $smileys = array( 
          ':wink:' => 'icon_wink.gif',
          ':lol:' => 'icon_lol.gif',
          ':cry:' => 'icon_cry.gif',
          ':evil:' => 'icon_evil.gif',
          ':twisted:' => 'icon_twisted.gif',
          ':roll:' => 'icon_rolleyes.gif',
          ':idea:' => 'icon_idea.gif',
          ':arrow:' => 'icon_arrow.gif',
          ':mrgreen:' => 'icon_mrgreen.gif',
          ':-)' => 'icon_smile.gif',
          ':)' => 'icon_smile.gif',
          ':-(' => 'icon_sad.gif',
          ':(' => 'icon_sad.gif',
          ';-)' => 'icon_wink.gif',
          ';)' => 'icon_wink.gif',
          ':!:' => 'icon_exclaim.gif',
          ':?:' => 'icon_question.gif',
          ':oops:' => 'icon_redface.gif',
          ':o' => 'icon_surprised.gif',
          ':-D' => 'icon_biggrin.gif',
          ':D' => 'icon_biggrin.gif',
          '8O' => 'icon_eek.gif',
          '8)' => 'icon_cool.gif',
          ':?' => 'icon_confused.gif',
          ':x' => 'icon_mad.gif',
          ':P' => 'icon_razz.gif',
          ':|' => 'icon_neutral.gif',
          );
      $url = $this->getAdminURL( ) . 'smiles/';
      $data = str_replace( '&quot;)', '")', $data);
      foreach ( $smileys as $smile => $img) {
          if ( $smile == ":oops:") {
              $data = str_replace( $smile, "<img src='" . $url . $img . "' alt='()'/>", $data);
          } else {
              $data = str_replace( $smile, "<img src='" . $url . $img . "' alt='" . $smile . "'/>", $data);
          } 
      } 
      $data = str_replace( '")', '&quot;)', $data);
  } 
  
  function doTemplateCommentsVar( &$item, &$comments){
     echo "\n".'<li id="comment'.$this->permacommentid.'"><address>[<a href="#comment'.$this->permacommentid.'" title="Comment Permalink">'.($this->commentSeq).'</a>]';
  } 

} 
?>