<?php

/**
  * BLOG:CMS: PHP/MySQL Personal Content Management System (CMS)
  * http://blogcms.com/
  * ----------------------------------------------------------------
  *
  * Copyright (C) 2003-2005 Radek HULN
  * http://hulan.cz/contact/
  *
  * Based on: 
  * ----------------------------------------------------------------
  * Nucleus: PHP/MySQL Weblog CMS (http://nucleuscms.org/) 
  * Copyright (C) 2002-2003 The Nucleus Group
  *
  * ----------------------------------------------------------------
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
  * of the License, or (at your option) any later version.
**/

class NP_WYSIWYG extends NucleusPlugin {

	function getName() 		{ return 'WYSIWYG'; }
	function getAuthor()  	{ return 'Radek HULAN'; }
	function getURL()  		{ return 'http://hulan.cz/blog/'; }
	function getVersion() 	{ return '1.0'; }
	function getDescription()
	{
		return 'XHTML edit tools.';
	}

	function supportsFeature($what) {
		switch($what)
		{
			case 'SqlTablePrefix':
				return 1;
			default:
				return 0;
		}
	}

	function install() {
		// create plugin options (per-blog options)
		$this->createMemberOption('use_wysiwyg', 'Use FCKEditor WYSIWYG editor - http://www.fckeditor.net/?', 'yesno', 'yes');
		// simple javascript editbar
		sql_query("UPDATE ".sql_table('config')." SET value='2' WHERE name='DisableJSTools'");
		// disable auto-linebreak conversions
		sql_query("UPDATE ".sql_table('blog')." SET bconvertbreaks=0");
	}

   function unInstall() {
     // restore to full toolbar
     sql_query("UPDATE ".sql_table('config')." SET value='0' WHERE name='DisableJSTools'");
   }

	function getEventList() {
		return array(
			'AdminPrePageHead',         // include javascript on admin add/edit pages
			'BookmarkletExtraHead',			// include javascript on bookmarklet pages
			'PreSendContentType', 			// we need to force text/html instead of application/xhtml+xml
			'PrepareItemForEdit',
			'PreAddItem',
			'PreUpdateItem'
		);
	}

	function event_PrepareItemForEdit($data) {
		$parts = array('body','more');
		foreach ($parts as $part) {
  		$data['item'][$part] = preg_replace('/<%image\((.*?)\)%>/', '[%image(\\1)%]', $data['item'][$part]);
  		$data['item'][$part] = preg_replace('/<%popup\((.*?)\)%>/', '[%popup(\\1)%]', $data['item'][$part]);
    }
	}

	function event_PreAddItem($data) {
		$parts = array('body','more');
		foreach ($parts as $part) {
		  // pseudo tags into BLOG:CMS pseudo-tags
  		$data[$part] = preg_replace('/\[%image\((.*?)\)%\]/', '<%image(\\1)%>', $data[$part]);
  		$data[$part] = preg_replace('/\[%popup\((.*?)\)%\]/', '<%popup(\\1)%>', $data[$part]);
  		// remove some strange gecko tags
  		$data[$part] = preg_replace('/ \_moz(.*?)\=\"(.*?)\"/', '', $data[$part]);
  		$data[$part] = preg_replace('/ type\=\"\_moz\"/', '', $data[$part]);
  		// cleanup
  		if (trim(strip_tags($data[$part]))=='') $data[$part]='';
  		// font tags into span
  		$data[$part] = preg_replace('/<font face=\"(.*?)\">(.*?)<\/font>/', '<span style="font-family:\\1">\\2</span>', $data[$part]);
  		// unnecessary <br/> before closing tags
  		$data[$part] = preg_replace('/<br\/>[\n|\r| ]<\/(.*?)>/', '</\\1>', $data[$part]);
  		$data[$part] = preg_replace('/<br\/><\/(.*?)>/', '</\\1>', $data[$part]);
  		// unnecessary self-closing <p/> tags
  		$data[$part] = preg_replace('/<p\/>/', '', $data[$part]);
  		// some other markup
  		$data[$part] = preg_replace('/border\=\"0\"/', '', $data[$part]);
    }
	}

	function event_PreUpdateItem($data) {
		$this->event_PreAddItem($data);
	}

	function event_BookmarkletExtraHead(&$data) {
		$this->_getExtraHead($data['extrahead']);
	}

	function event_AdminPrePageHead(&$data) {
		$action = $data['action'];
		if (($action != 'createitem') && ($action != 'itemedit')) return;
		$this->_getExtraHead($data['extrahead']);
	}

  	var $bUseEditor;
  
	function _getExtraHead(&$extrahead) {
		global $CONF, $member;
		$this->bUseEditor	= ($this->getMemberOption($member->getID(), 'use_wysiwyg') == 'yes');
		if ($this->bUseEditor) {
   		$baseUrl = $this->getAdminURL();
	    $editorCode = '<script type="text/javascript" src="'.$baseUrl.'fckeditor.js"></script>'."\n"
	            . '<script type="text/javascript">'."\n"
							. 'window.onload = function(){'."\n"
    	        . 'var editor1=new FCKeditor("more",605,390,"Default","");'."\n"
    	        . 'editor1.BasePath="'.$baseUrl.'";'."\n" 
    	        . 'editor1.MediaURL = "'.$CONF['MediaURL'].'";'."\n"
    	        . 'editor1.AuthorID = "'.strval($member->getID()).'";'."\n"
    	        . 'editor1.Config["LinkBrowserURL"] = editor1.BasePath+"editor/filemanager/browser/default/browser.html?Connector=connectors/php/connector.php&ServerPath='.$CONF['MediaURL'].strval($member->getID()).'";'."\n"
    	        . 'editor1.Config["ImageBrowserURL"] = editor1.BasePath+"editor/filemanager/browser/default/browser.html?Connector=connectors/php/connector.php&Type=Image&ServerPath='.$CONF['MediaURL'].strval($member->getID()).'";'."\n"
    	        . 'editor1.Config["FlashBrowserURL"] = editor1.BasePath+"editor/filemanager/browser/default/browser.html?Connector=connectors/php/connector.php&Type=Flash&ServerPath='.$CONF['MediaURL'].strval($member->getID()).'";'."\n"
    	        . 'editor1.ReplaceTextarea();'."\n"
    	        . 'var usingFCK = editor1._IsCompatibleBrowser() ? true : false;'."\n"
    	        . 'var editor2=new FCKeditor("body",605,390,"Default","");'."\n"
    	        . 'editor2.BasePath="'.$baseUrl.'";'."\n" 
    	        . 'editor2.MediaURL = "'.$CONF['MediaURL'].'";'."\n"
    	        . 'editor2.AuthorID = "'.strval($member->getID()).'";'."\n"
    	        . 'editor2.Config["LinkBrowserURL"] = editor2.BasePath+"editor/filemanager/browser/default/browser.html?Connector=connectors/php/connector.php&ServerPath='.$CONF['MediaURL'].strval($member->getID()).'";'."\n"
    	        . 'editor2.Config["ImageBrowserURL"] = editor2.BasePath+"editor/filemanager/browser/default/browser.html?Connector=connectors/php/connector.php&Type=Image&ServerPath='.$CONF['MediaURL'].strval($member->getID()).'";'."\n"
    	        . 'editor2.Config["FlashBrowserURL"] = editor2.BasePath+"editor/filemanager/browser/default/browser.html?Connector=connectors/php/connector.php&Type=Flash&ServerPath='.$CONF['MediaURL'].strval($member->getID()).'";'."\n"
    	        . 'editor2.ReplaceTextarea();'."\n"
    	        . 'if (usingFCK) hideElements(); '."\n";
    	if (strstr(serverVar('REQUEST_URI'),'bookmarklet'))
              $editorCode.= 'nucleus_initbm();'."\n";
      $editorCode.= '}; '."\n"
	            . '</script>'."\n";
   		$extrahead .= $editorCode;
		}
	}

	function event_PreSendContentType(&$data) {
		$pageType = $data['pageType'];
		if ($pageType == 'skin')
			return;
		if (	($pageType != 'bookmarklet-add')
			&&	($pageType != 'bookmarklet-edit')
			&&	($pageType != 'admin-createitem')
			&& 	($pageType != 'admin-itemedit')
			)
			return;
		if ($data['contentType'] == 'application/xhtml+xml') $data['contentType'] = 'text/html';
	}

}
?>